Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(993)

Unified Diff: net/spdy/spdy_buffer_unittest.cc

Issue 1852423004: Implement SpdySerializedFrame move semantics. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/spdy_buffer.cc ('k') | net/spdy/spdy_frame_builder.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_buffer_unittest.cc
diff --git a/net/spdy/spdy_buffer_unittest.cc b/net/spdy/spdy_buffer_unittest.cc
index 4200916c426c6120231e75a8a351e5198117676b..46a5c2b63fdffe0a76b6133056f1302cca29759b 100644
--- a/net/spdy/spdy_buffer_unittest.cc
+++ b/net/spdy/spdy_buffer_unittest.cc
@@ -29,13 +29,11 @@ std::string BufferToString(const SpdyBuffer& buffer) {
return std::string(buffer.GetRemainingData(), buffer.GetRemainingSize());
}
// Construct a SpdyBuffer from a SpdyFrame and make sure its data
// points to the frame's underlying data.
TEST_F(SpdyBufferTest, FrameConstructor) {
- SpdyBuffer buffer(
- scoped_ptr<SpdyFrame>(
- new SpdyFrame(const_cast<char*>(kData), kDataSize,
- false /* owns_buffer */)));
+ SpdyBuffer buffer(scoped_ptr<SpdySerializedFrame>(new SpdySerializedFrame(
+ const_cast<char*>(kData), kDataSize, false /* owns_buffer */)));
EXPECT_EQ(kData, buffer.GetRemainingData());
EXPECT_EQ(kDataSize, buffer.GetRemainingSize());
« no previous file with comments | « net/spdy/spdy_buffer.cc ('k') | net/spdy/spdy_frame_builder.h » ('j') | no next file with comments »
@@ -29,13 +29,11 @@ std::string BufferToString(const SpdyBuffer& buffer) {
return std::string(buffer.GetRemainingData(), buffer.GetRemainingSize());
}
-// Construct a SpdyBuffer from a SpdyFrame and make sure its data
+// Construct a SpdyBuffer from a SpdySerializedFrame and make sure its data
// points to the frame's underlying data.
TEST_F(SpdyBufferTest, FrameConstructor) {

Powered by Google App Engine
This is Rietveld 408576698